@@ -465,7 +465,8 @@ def hackathon():
 @hackathon.command("update")
 @click.option("--codename", type=str, required=True)
 @click.option("--hackathon_url", type=str, required=True)
-def hackathon_update(codename, hackathon_url):
+@click.option("--token", type=str, required=True)
+def hackathon_update(codename, hackathon_url, token):
     """
     Update hackathon script and data
     """
@@ -480,7 +481,7 @@ def hackathon_update(codename, hackathon_url):
     }
     response = requests.put(
         hackathon_url,
-        headers={"Authorization": f"Token {config['token']}"},
+        headers={"Authorization": f"Token {token}"},
         files=files,
     )
     try:
